zfit package
============

.. automodule:: zfit
    :members:
    :undoc-members:
    :show-inheritance:
    :inherited-members:


Subpackages
-----------

.. toctree::

    zfit.core
    zfit.minimizers
    zfit.models
    zfit.util
    zfit.ztf

Submodules
----------

.. toctree::

   zfit.constraint
   zfit.data
   zfit.func
   zfit.loss
   zfit.minimize
   zfit.old_ztf
   zfit.pdf
   zfit.sample
   zfit.settings

